Arguments
model
A model object obtained as the return value from eval.on.grid.
start
Start value passed on to optim when performing the marginal
likelihood optimisation to find appropriate values for the
hyperparameters for the GPR regression function.
gr
Set to TRUE if gradient information should be passed to
optim. If false, optim uses a finite difference
approximation of the gradient when performing the optimisation of the hyperparameters.
method
The optimisation method to be used by optim. One of
"Nelder-Mead", "BFGS", "CG", "L-BFGS-B",
"SANN" or "Brent".
lower
A numeric, atomic vector containing the lower limits for the
hyperparameters. The first entry is for the standard deviation
parameter and the remaining entries are for the length parameters.
If supplied, all elements must be >= 0.
upper
A numeric, atomic vector containing the upper limits for the
hyperparameters. The first entry is for the standard deviation
parameter and the remaining entries are for the length parameters.
control
A list of control parameters passed on to optim.