eval.on.grid. This is a generic function for S3 objects.
fit.loess(model, span = 0.75, degree = 2)eval.on.grid.
model$regression.fun and
model$gpr.hyper.params (set to NA). See sim.model for a
description of these components.
loess in package stats to perform a
regression. Note that the number of decision variables must be
between 1 and 4, since this is the range supported by loess. The formula passed as formula to loess has the form
"y ~ x1 + x2" (for two decision variables, and correspondingly
for any other number between 1 and 4). The span and
degree arguments are passed on to loess as
given. Further, surface = "direct" is used as a loess
control value in order to allow for extrapolation for the fitted
function. For the remaining arguments of loess, the default values are used.
fit.gpr