Learn R Programming

bdpopt (version 1.0-1)

fit.loess.sim.model: Fit A Local Polynomial Regression Function

Description

fit.loess method for objects of class sim.model.

Usage

"fit.loess"(model, span = 0.75, degree = 2)

Arguments

model
A model object obtained as the return value from eval.on.grid.
span
A parameter which controls the degree of smoothing.
degree
The degree of the polynomials to be used, normally 1 or 2.

Details

See fit.loess for further documentation.